pyHMSA TIFF
===========

.. image:: https://badge.fury.io/py/pyhmsa-tiff.svg
   :target: http://badge.fury.io/py/pyhmsa-tiff

.. image:: https://travis-ci.org/pyhmsa/pyhmsa-tiff.svg?branch=master
   :target: https://travis-ci.org/pyhmsa/pyhmsa-tiff

Exporter for `pyHMSA <https://pypi.python.org/pypi/pyHMSA>`_ of HMSA data 
to TIFF images.

The library is provided under the MIT license.

More information can be found at the website:

http://pyhmsa.readthedocs.org

The most current development version is always available from our
GitHub repository:

https://github.com/pyhmsa/pyhmsa-tiff

pyHMSA-tiff was developed as part of the doctorate thesis project of 
Philippe T. Pinard at RWTH Aachen University (Aachen, Germany) under the 
supervision of Dr. Silvia Richter.
